@@ -1,5 +1,5 @@
 /*===========================================================================
- *           R-ScaLAPACK version 0.2:  ScaLAPACK interface to R
+ *           R-ScaLAPACK version 0.3.x:  R interface to ScaLAPACK
  *              Oak Ridge National Laboratory, Oak Ridge TN.
  *      Authors: David Bauer, Nagiza. F. Samatova, Srikanth Yoginath
  *     Contact: Nagiza F. Samatova; (865) 241-4351; samatovan@ornl.gov
@@ -73,7 +73,7 @@ int PA_Init() {
 SEXP PA_Exit() {
 	/*MPI_Comm_free(&childComm);*/
 	MPI_Finalize();
-	return AsInt(1);
+	return R_NilValue;
 }
 
 /* **** PA_Exec ****
